@@ -1,6 +1,7 @@
                         
 """this is a eaxmple of print out every element in list"""
-def print_it(the_list,tabf=False,level=0): 
+def print_it(the_list,tabf=False,level=0):
+        #tabf=table function default close
         for each_item in the_list:
                 if isinstance(each_item,list):
                         print_it(each_item,tabf,level+1)
@@ -9,5 +10,4 @@ def print_it(the_list,tabf=False,level=0):
                                 for tab in range(level):
                                     print("\t",end='')
                         print(each_item)
-cast=["zhao","qian","sun","li",["zhou jia","wu yi",["zheng bing wu"]]]
-print_it(cast,1,0)
+
